@@ -29,10 +29,6 @@
  * going from fd to pci id via fstat and udev.
  */
 
-
-#ifdef HAVE_CONFIG_H
-#include "config.h"
-#endif
 #include <errno.h>
 #include <stdio.h>
 #include <stdlib.h>
@@ -41,9 +37,12 @@
 #include <unistd.h>
 #include <sys/stat.h>
 #include <sys/types.h>
-#ifdef HAVE_SYS_MKDEV_H
+#ifdef MAJOR_IN_MKDEV
 #include <sys/mkdev.h>
 #endif
+#ifdef MAJOR_IN_SYSMACROS
+#include <sys/sysmacros.h>
+#endif
 
 #include "libdrm_macros.h"
 #include "internal.h"
@@ -107,27 +106,27 @@ linux_from_sysfs(int fd, struct kms_driver **out)
 	if (ret)
 		return ret;
 
-#ifdef HAVE_INTEL
+#if HAVE_INTEL
 	if (!strcmp(name, "intel"))
 		ret = intel_create(fd, out);
 	else
 #endif
-#ifdef HAVE_VMWGFX
+#if HAVE_VMWGFX
 	if (!strcmp(name, "vmwgfx"))
 		ret = vmwgfx_create(fd, out);
 	else
 #endif
-#ifdef HAVE_NOUVEAU
+#if HAVE_NOUVEAU
 	if (!strcmp(name, "nouveau"))
 		ret = nouveau_create(fd, out);
 	else
 #endif
-#ifdef HAVE_RADEON
+#if HAVE_RADEON
 	if (!strcmp(name, "radeon"))
 		ret = radeon_create(fd, out);
 	else
 #endif
-#ifdef HAVE_EXYNOS
+#if HAVE_EXYNOS
 	if (!strcmp(name, "exynos"))
 		ret = exynos_create(fd, out);
 	else
@@ -138,105 +137,11 @@ linux_from_sysfs(int fd, struct kms_driver **out)
 	return ret;
 }
 
-#if 0
-#define LIBUDEV_I_KNOW_THE_API_IS_SUBJECT_TO_CHANGE
-#include <libudev.h>
-
-struct create_record
-{
-	unsigned vendor;
-	unsigned chip;
-	int (*func)(int fd, struct kms_driver **out);
-};
-
-static const struct create_record table[] = {
-	{ 0x8086, 0x2a42, intel_create }, /* i965 */
-#ifdef HAVE_VMWGFX
-	{ 0x15ad, 0x0405, vmwgfx_create }, /* VMware vGPU */
-#endif
-	{ 0, 0, NULL },
-};
-
-static int
-linux_get_pciid_from_fd(int fd, unsigned *vendor_id, unsigned *chip_id)
-{
-	struct udev *udev;
-	struct udev_device *device;
-	struct udev_device *parent;
-	const char *pci_id;
-	struct stat buffer;
-	int ret;
-
-	ret = fstat(fd, &buffer);
-	if (ret)
-		return -EINVAL;
-
-	if (!S_ISCHR(buffer.st_mode))
-		return -EINVAL;
-
-	udev = udev_new();
-	if (!udev)
-		return -ENOMEM;
-
-	device = udev_device_new_from_devnum(udev, 'c', buffer.st_rdev);
-	if (!device)
-		goto err_free_udev;
-
-	parent = udev_device_get_parent(device);
-	if (!parent)
-		goto err_free_device;
-
-	pci_id = udev_device_get_property_value(parent, "PCI_ID");
-	if (!pci_id)
-		goto err_free_device;
-
-	if (sscanf(pci_id, "%x:%x", vendor_id, chip_id) != 2)
-		goto err_free_device;
-
-	udev_device_unref(device);
-	udev_unref(udev);
-
-	return 0;
-
-err_free_device:
-	udev_device_unref(device);
-err_free_udev:
-	udev_unref(udev);
-	return -EINVAL;
-}
-
-static int
-linux_from_udev(int fd, struct kms_driver **out)
-{
-	unsigned vendor_id, chip_id;
-	int ret, i;
-
-	ret = linux_get_pciid_from_fd(fd, &vendor_id, &chip_id);
-	if (ret)
-		return ret;
-
-	for (i = 0; table[i].func; i++)
-		if (table[i].vendor == vendor_id && table[i].chip == chip_id)
-			return table[i].func(fd, out);
-
-	return -ENOSYS;
-}
-#else
-static int
-linux_from_udev(int fd, struct kms_driver **out)
-{
-	return -ENOSYS;
-}
-#endif
-
 drm_private int
 linux_create(int fd, struct kms_driver **out)
 {
 	if (!dumb_create(fd, out))
 		return 0;
 
-	if (!linux_from_udev(fd, out))
-		return 0;
-
 	return linux_from_sysfs(fd, out);
 }
